@@ -5,8 +5,11 @@
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 #error_reporting(E_ALL | E_STRICT);
-snmp_set_oid_numeric_print(SNMP_OID_OUTPUT_NUMERIC);
-snmp_set_quick_print(1);
+
+if (function_exists('snmp_set_output_format'))
+    snmp_set_output_format(SNMP_OID_OUTPUT_NUMERIC);
+if (function_exists('snmp_set_quick_print'))
+    snmp_set_quick_print(1);
 define('JFFNMS_VERSION', '0.9.1');
 
 class JffnmsConfig
@@ -23,6 +26,7 @@ class JffnmsConfig
       die("Cannot find configuration default file \"$default_filename\".");
     $this->_parse_defaults_file($this->config_dir.'/'.$default_filename);
     $this->_parse_config_file($this->config_dir.'/'.$config_filename);
+    $this->_check_configuration();
 
   }
 
@@ -45,16 +49,33 @@ class JffnmsConfig
 
     $new_config = '';
     foreach($this->configs as $key => $value)
-      if ($value != $this->default_configs[$key]['default'])
-        $new_config .= "$key = $value\n";
-
+    {
+        if ($key == 'logging_file')
+            continue;
+        if (!array_key_exists('type', $this->default_configs[$key]))
+            $config_type='plain';
+        else
+            $config_type = $this->default_configs[$key]['type'];
+        switch($config_type)
+        {
+        case 'db':
+        case 'menu':
+        case 'phpmodule':
+        case 'phpconf':
+            break; # this lot dont get saved
+        default:
+            if (!array_key_exists('default', $this->default_configs[$key]) ||
+                $value != $this->default_configs[$key]['default'])
+                $new_config .= "$key = $value\n";
+        }
+    }
     if ( ($fp = fopen($new_config_name, 'w+', FALSE)) === FALSE)
       die("Cannot open new config file '$new_config_name'");
     fputs($fp, $new_config);
     fclose($fp);
 
-    if ($really == TRUE && file_exists($new_config_name))
-      copy($new_config_name, $file);
+    if (file_exists($new_config_name))
+      copy($new_config_name, $config_file);
   }
 
 
@@ -87,6 +108,8 @@ class JffnmsConfig
 
   private function _parse_config_file($filename)
   {
+    if (!is_readable($filename))
+        return;
     if ( ($fp = fopen($filename, 'r', FALSE)) === FALSE)
         return;
     while ($fp != feof($fp))
@@ -111,7 +134,7 @@ class JffnmsConfig
     if ($this->get('jffnms_configured') !=1)
     {
       // Not yet configured and we are running on a website
-      if (strpos($_SERVER['REQUEST_URI'],$jffnms_setup_page) === false)
+      if (PHP_SAPI != 'cli' && strpos($_SERVER['REQUEST_URI'],$jffnms_setup_page) === false)
       {
         $jffnms_rel_path = str_replace($jffnms_setup_page,"",$_SERVER['REQUEST_URI']);
         //we are not in the setup page
@@ -122,9 +145,11 @@ class JffnmsConfig
       }
         header('Location: '.$jffnms_setup_location);			//redirect to setup
         die();    
-      } else 
+      } else {
         // Help setup with its real path
         $this->set('jffnms_real_path', str_replace('/conf', '', str_replace('\conf', '', dirname(__FILE__)))); 
+        $this->set('jffnms_rel_path', str_replace($jffnms_setup_page, '', $_SERVER['PHP_SELF']));
+      }
     }
   } # check_configuration()
 
