@@ -118,7 +118,7 @@ function iad_main($opt_host, $opt_itype, $opt_children)
         $Parent->check_children();
         $Parent->item_check_poll_time();
         $Parent->children_start();
-        iad_read_children(&$Parent);
+        iad_read_children($Parent);
         $Parent->work_children();
         $Parent->print_status();
 
