@@ -1,4 +1,4 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2002-2005> David LIMA <dlima@fr.scc.com> 
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
