@@ -1,4 +1,4 @@
-<?
+<?php
 /* Satellite Sync. This file is part of JFFNMS
  * Copyright (C) <2003> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
