@@ -1,10 +1,12 @@
-<?
+<?php
 /* This file is part of JFFNMS
  * Copyright (C) <2006> Javier Szyszlican <javier@szysz.com>
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
-    function storage_interface_parse_description ($descr) {
+function storage_interface_parse_description ($descr) {
+    $interface = '';
+    $description = '';
 
 	$label_hex = strpos($descr,"Hex");
 	if ($label_hex!==FALSE)   // UCD-SNMP 4.2.4 fix
