@@ -274,7 +274,7 @@ function time_msec_diff($from, $to=FALSE)
   return $result;
     }
 
-    function ad_set_default($var,$value) {
+    function ad_set_default(&$var,$value) {
   if (!isset($var)) $var = $value;
     }
 
@@ -434,19 +434,18 @@ function time_hms ()
   return '00:00';
 }
 
-    function array_record_search ($rows, $needle_field, $needle_value) {
-  $result = array();
+function array_record_search ($rows, $needle_field, $needle_value)
+{
+    $result = array();
   
-  if (is_array($rows)) {
-      reset($rows);
-
-      while (list ($id, $row) = each ($rows))
-    if ($row[$needle_field] == $needle_value)
-        $result[$id]=$row;
-  }
-  
-  return $result;
-    }    
+    if (is_array($rows)) {
+        reset($rows);
+        while (list ($id, $row) = each ($rows))
+            if ($row[$needle_field] == $needle_value)
+                $result[$id]=$row;
+    }
+    return $result;
+}    
     
     function byte_format($input, $dec = 0) {
   $prefix_arr = array("", "K", "M", "G", "T");
@@ -482,7 +481,7 @@ function array_item_blank(&$arr, $key)
 
 function array_fetch(&$arr, $key, $default)
 {
-  if (array_key_exists($key, $arr))
+  if (is_array($arr) and array_key_exists($key, $arr))
     return $arr[$key];
   return $default;
 }
