@@ -182,6 +182,9 @@ function rrd_grapher($id, $graph_function, $sizex, $sizey, $title, $graph_time_s
   if (!$graph_function || !$id)
     return FALSE;
 
+  if (!isset($Interfaces))
+      $Interfaces = new JffnmsInterfaces();
+
   $interface_data = $Interfaces->get_all($id);
   $rrd_path = $Config->get('rrd_real_path');
       
