@@ -174,7 +174,7 @@ function select_pollers ($name,$id, $add_data = NULL, $onchange = "", $params =
 
 function select_pollers_backend ($name,$id, $add_data = NULL, $onchange = "", $params = array())
 {
-  $Backends = new JffnmsPollers_backends;
+  $Backends = new JffnmsPollers_backend;
   return select_object($Backends,$name,$id,$add_data,'id','description',$params,1,$onchange);
 } 
 
